import time
from fastapi import FastAPI, Query
from zapv2 import ZAPv2
from pprint import pprint
import nmap
from starlette.middleware.cors import CORSMiddleware


app = FastAPI()

# Define the list of allowed origins (you can customize this based on your requirements)
origins = [
    "http://localhost",
    "http://localhost:3000",
    # Add more origins as needed
]

# Add CORS middleware to your FastAPI app
app.add_middleware(
    CORSMiddleware,
    allow_origins=origins,
    allow_credentials=True,
    allow_methods=["*"],  # You can restrict HTTP methods as needed
    allow_headers=["*"],  # You can restrict headers as needed
)

# Initialize ZAP API client
target = 'https://public-firing-range.appspot.com'
apiKey = '7jc5np5ko77i54hrh5jf8estra'  # Replace with your actual ZAP API key
zap = ZAPv2(apikey=apiKey, proxies={'http': 'http://127.0.0.1:8080', 'https': 'http://127.0.0.1:8080'})


# Helper function to wait for spider = completion
def wait_for_spider_completion(scan_id):
    while True:
        status = zap.spider.status(scan_id)
        try:
            int_status = int(status)
            if int_status >= 100:
                break
        except ValueError:
            print("Invalid status:", status)
            break
        time.sleep(1)
    return

# benchmark categories
def get_website_benchmarks(website_url):
    dummy_benchmarks = {
        "Website": website_url,
        "Benchmarks": [
            {
                "name": "Identity and Access Management",
                "checks": [
                    {"name": "Ensure that there are no privileged users", "status": "Passed",
                     "details": "There are no privileged users in the Azure environment."},
                ],
            },
            {
                "name": "Security Center",
                "checks": [
                    {"name": "Ensure that automatic provisioning of monitoring agents is set to 'On'",
                     "status": "Passed",
                     "details": "Automatic provisioning of monitoring agents is enabled in the Azure environment."},
                ],
            },
            {
                "name": "Network Security",
                "checks": [
                    {
                        "name": "Ensure that the default Azure policy for monitoring of virtual machines is set to 'Enabled'",
                        "status": "Passed",
                        "details": "The default Azure policy for monitoring of virtual machines is set to 'Enabled'."},
                ],
            },
            {
                "name": "Storage Security",
                "checks": [
                    {
                        "name": "Ensure that the default Azure policy for monitoring of storage accounts is set to 'Enabled'",
                        "status": "Passed",
                        "details": "The default Azure policy for monitoring of storage accounts is set to 'Enabled'."},
                ],
            },
            {
                "name": "Network Configuration",
                "checks": [
                    {"name": "Ensure firewall rules are configured", "status": "Passed",
                     "details": "Firewall rules are configured as per policy."},
                    {"name": "Ensure VLANs are correctly configured", "status": "Failed",
                     "details": "VLANs are not correctly configured."},
                ],
            },
            {
                "name": "Data Security",
                "checks": [
                    {"name": "Ensure encryption is enabled for data at rest", "status": "Passed",
                     "details": "Data at rest is encrypted."},
                    {"name": "Ensure data retention policies are defined", "status": "Passed",
                     "details": "Data retention policies are defined."},
                    # Add more checks as needed
                ],
            },
            {
                "name": "Identity and Access Management",
                "checks": [
                    {"name": "Ensure no privileged users exist", "status": "Passed",
                     "details": "No privileged users found."},
                    {"name": "Enable multi-factor authentication (MFA) for all users", "status": "Failed",
                     "details": "MFA not enabled for all users."},
                    {"name": "Regularly review and remove inactive user accounts", "status": "Passed",
                     "details": "Inactive user accounts removed."},
                ],
            },
            {
                "name": "Security Center",
                "checks": [
                    {"name": "Enable automatic monitoring agent provisioning", "status": "Passed",
                     "details": "Automatic provisioning enabled."},
                    {"name": "Regularly review security alerts", "status": "Failed",
                     "details": "Security alerts not regularly reviewed."},
                    {"name": "Implement threat detection policies", "status": "Passed",
                     "details": "Threat detection policies implemented."},
                ],
            },
            {
                "name": "Network Security",
                "checks": [
                    {"name": "Configure firewall rules", "status": "Passed", "details": "Firewall rules configured."},
                    {"name": "Regularly update intrusion detection systems (IDS)", "status": "Failed",
                     "details": "IDS not regularly updated."},
                    {"name": "Implement network segmentation", "status": "Passed",
                     "details": "Network segmented for security."},
                ],
            },
            {
                "name": "Data Security",
                "checks": [
                    {"name": "Encrypt data at rest", "status": "Passed", "details": "Data at rest encrypted."},
                    {"name": "Implement data retention policies", "status": "Passed",
                     "details": "Data retention policies implemented."},
                    {"name": "Regularly backup critical data", "status": "Failed",
                     "details": "Critical data not regularly backed up."},
                ],
            },
            {
                "name": "Incident Response",
                "checks": [
                    {"name": "Develop an incident response plan", "status": "Passed",
                     "details": "Incident response plan developed."},
                    {"name": "Regularly test the incident response plan", "status": "Failed",
                     "details": "Incident response plan not regularly tested."},
                    {"name": "Establish communication channels for incidents", "status": "Passed",
                     "details": "Communication channels established."},
                ],
            },
            {
                "name": "Data Privacy",
                "checks": [
                    {"name": "Obtain user consent for data processing", "status": "Failed",
                     "details": "User consent not obtained."},
                    {"name": "Implement data anonymization techniques", "status": "Passed",
                     "details": "Data anonymization techniques implemented."},
                    {"name": "Regularly audit data access logs", "status": "Passed",
                     "details": "Data access logs audited regularly."},
                ],
            },
            {
                "name": "Endpoint Security",
                "checks": [
                    {"name": "Install antivirus and anti-malware software", "status": "Passed",
                     "details": "Antivirus and anti-malware software installed."},
                    {"name": "Configure endpoint firewall rules", "status": "Failed",
                     "details": "Endpoint firewall rules not configured."},
                    {"name": "Regularly update endpoint security software", "status": "Passed",
                     "details": "Endpoint security software updated regularly."},
                ],
            },
            {
                "name": "Vendor Management",
                "checks": [
                    {"name": "Assess third-party vendor security", "status": "Passed",
                     "details": "Third-party vendor security assessed."},
                    {"name": "Establish contractual security requirements", "status": "Failed",
                     "details": "Contractual security requirements not established."},
                    {"name": "Regularly review vendor compliance", "status": "Passed",
                     "details": "Vendor compliance reviewed regularly."},
                ],
            },
            {
                "name": "Password Management",
                "checks": [
                    {"name": "Enforce strong password policies", "status": "Passed",
                     "details": "Strong password policies enforced."},
                    {"name": "Implement password rotation policies", "status": "Failed",
                     "details": "Password rotation policies not implemented."},
                    {"name": "Regularly audit user passwords", "status": "Passed",
                     "details": "User passwords audited regularly."},
                ],
            },
            {
                "name": "Physical Security",
                "checks": [
                    {"name": "Control physical access to data centers", "status": "Failed",
                     "details": "Physical access control not implemented."},
                    {"name": "Use surveillance cameras in sensitive areas", "status": "Passed",
                     "details": "Surveillance cameras used in sensitive areas."},
                    {"name": "Implement biometric authentication for access", "status": "Passed",
                     "details": "Biometric authentication implemented for access."},
                ],
            },
            {
                "name": "Patch Management",
                "checks": [
                    {"name": "Regularly apply OS and software patches", "status": "Passed",
                     "details": "OS and software patches applied regularly."},
                    {"name": "Test patches in a controlled environment", "status": "Failed",
                     "details": "Patches not tested in a controlled environment."},
                    {"name": "Maintain a list of critical systems for patching", "status": "Passed",
                     "details": "List of critical systems maintained."},
                ],
            },
            {
                "name": "Network Security",
                "checks": [
                    {"name": "Implement intrusion detection and prevention", "status": "Passed",
                     "details": "Intrusion detection and prevention systems implemented."},
                    {"name": "Configure network segmentation for sensitive data", "status": "Failed",
                     "details": "Network segmentation not configured for sensitive data."},
                    {"name": "Conduct regular network vulnerability scans", "status": "Passed",
                     "details": "Network vulnerability scans conducted regularly."},
                ],
            },
            {
                "name": "Asset Management",
                "checks": [
                    {"name": "Maintain an inventory of all IT assets", "status": "Passed",
                     "details": "Inventory of all IT assets maintained."},
                    {"name": "Implement a software licensing policy", "status": "Failed",
                     "details": "Software licensing policy not implemented."},
                    {"name": "Regularly update asset inventory records", "status": "Passed",
                     "details": "Asset inventory records updated regularly."},
                ],
            },
            {
                "name": "Incident Response",
                "checks": [
                    {"name": "Develop an incident response plan", "status": "Passed",
                     "details": "Incident response plan developed."},
                    {"name": "Regularly test the incident response plan", "status": "Failed",
                     "details": "Incident response plan not regularly tested."},
                    {"name": "Establish communication channels for incidents", "status": "Passed",
                     "details": "Communication channels established."},
                ],
            },
            {
                "name": "Identity and Access Management",
                "checks": [
                    {"name": "Ensure that there are no privileged users", "status": "Passed",
                     "details": "There are no privileged users in the Azure environment."},
                    {"name": "Ensure multi-factor authentication is enabled for privileged users", "status": "Failed",
                     "details": "Multi-factor authentication is not enabled for privileged users."},
                    {"name": "Regularly review and update user access permissions", "status": "Passed",
                     "details": "User access permissions are regularly reviewed and updated."},
                ],
            },
            {
                "name": "Security Center",
                "checks": [
                    {"name": "Ensure that automatic provisioning of monitoring agents is set to 'On'",
                     "status": "Passed",
                     "details": "Automatic provisioning of monitoring agents is enabled in the Azure environment."},
                    {"name": "Enable Azure Security Center Standard tier", "status": "Failed",
                     "details": "Azure Security Center Standard tier is not enabled."},
                    {"name": "Configure security policies in Azure Security Center", "status": "Passed",
                     "details": "Security policies are configured in Azure Security Center."},
                ],
            },
            {
                "name": "Network Security",
                "checks": [
                    {
                        "name": "Ensure that the default Azure policy for monitoring of virtual machines is set to 'Enabled'",
                        "status": "Passed",
                        "details": "The default Azure policy for monitoring of virtual machines is set to 'Enabled'."},
                    {"name": "Implement network security groups (NSGs) to restrict traffic", "status": "Failed",
                     "details": "Network security groups (NSGs) are not implemented."},
                    {"name": "Regularly review network security rules", "status": "Passed",
                     "details": "Network security rules are regularly reviewed."},
                ],
            },
            {
                "name": "Storage Security",
                "checks": [
                    {
                        "name": "Ensure that the default Azure policy for monitoring of storage accounts is set to 'Enabled'",
                        "status": "Passed",
                        "details": "The default Azure policy for monitoring of storage accounts is set to 'Enabled'."},
                    {"name": "Encrypt data at rest in Azure Storage", "status": "Failed",
                     "details": "Data at rest in Azure Storage is not encrypted."},
                    {"name": "Implement role-based access control (RBAC) for storage accounts", "status": "Passed",
                     "details": "RBAC is implemented for storage accounts."},
                ],
            },
            {
                "name": "Logging and Monitoring",
                "checks": [
                    {"name": "Enable Azure Monitor for VMs", "status": "Passed",
                     "details": "Azure Monitor for VMs is enabled."},
                    {"name": "Set up alerting for critical events", "status": "Failed",
                     "details": "Alerting for critical events is not set up."},
                    {"name": "Configure log retention policies", "status": "Passed",
                     "details": "Log retention policies are configured."},
                ],
            },
            {
                "name": "Data Encryption",
                "checks": [
                    {"name": "Enable encryption for Azure SQL databases", "status": "Passed",
                     "details": "Encryption is enabled for Azure SQL databases."},
                    {"name": "Implement Azure Key Vault for managing encryption keys", "status": "Failed",
                     "details": "Azure Key Vault is not implemented for managing encryption keys."},
                    {"name": "Enable data encryption in transit", "status": "Passed",
                     "details": "Data encryption in transit is enabled."},
                ],
            },
            {
                "name": "Backup and Disaster Recovery",
                "checks": [
                    {"name": "Set up automated backups for critical data", "status": "Passed",
                     "details": "Automated backups for critical data are configured."},
                    {"name": "Test and document disaster recovery procedures", "status": "Failed",
                     "details": "Disaster recovery procedures are not tested and documented."},
                    {"name": "Implement geo-redundancy for critical resources", "status": "Passed",
                     "details": "Geo-redundancy is implemented for critical resources."},
                ],
            },
            {
                "name": "Compliance and Governance",
                "checks": [
                    {"name": "Regularly audit and report on compliance", "status": "Failed",
                     "details": "Regular compliance audits and reporting are not in place."},
                    {"name": "Implement Azure Policy for resource governance", "status": "Passed",
                     "details": "Azure Policy is implemented for resource governance."},
                    {"name": "Enforce compliance with industry-specific standards", "status": "Passed",
                     "details": "Industry-specific compliance standards are enforced."},
                ],
            },
            {
                "name": "Identity and Access Management",
                "checks": [
                    {"name": "Implement least privilege access", "status": "Passed",
                     "details": "Least privilege access is implemented for users and roles."},
                    {"name": "Enable Azure AD Identity Protection", "status": "Failed",
                     "details": "Azure AD Identity Protection is not enabled."},
                    {"name": "Monitor and respond to identity-related threats", "status": "Passed",
                     "details": "Identity-related threats are monitored and responded to."},
                ],
            },
            {
                "name": "Container Security",
                "checks": [
                    {"name": "Use Azure Kubernetes Service (AKS) for container orchestration", "status": "Passed",
                     "details": "Azure AKS is used for container orchestration."},
                    {"name": "Implement container image scanning for vulnerabilities", "status": "Failed",
                     "details": "Container image scanning for vulnerabilities is not implemented."},
                    {"name": "Apply network policies for container communication", "status": "Passed",
                     "details": "Network policies are applied for container communication."},
                ],
            },
            {
                "name": "Serverless Security",
                "checks": [
                    {"name": "Implement Azure Functions for serverless computing", "status": "Passed",
                     "details": "Azure Functions are used for serverless computing."},
                    {"name": "Enable Azure Logic App security features", "status": "Failed",
                     "details": "Azure Logic App security features are not enabled."},
                    {"name": "Monitor serverless function execution for anomalies", "status": "Passed",
                     "details": "Serverless function execution is monitored for anomalies."},
                ],
            },
            {
                "name": "Data Backup and Retention",
                "checks": [
                    {"name": "Set up automated data backups for all critical databases", "status": "Passed",
                     "details": "Automated data backups are configured for all critical databases."},
                    {"name": "Define data retention policies for compliance", "status": "Failed",
                     "details": "Data retention policies for compliance are not defined."},
                    {"name": "Regularly test data restoration procedures", "status": "Passed",
                     "details": "Data restoration procedures are regularly tested."},
                ],
            },
            {
                "name": "Multi-Factor Authentication (MFA)",
                "checks": [
                    {"name": "Enforce MFA for all privileged user accounts", "status": "Passed",
                     "details": "MFA is enforced for all privileged user accounts."},
                    {"name": "Implement conditional access policies for MFA", "status": "Failed",
                     "details": "Conditional access policies for MFA are not implemented."},
                    {"name": "Monitor and log MFA authentication events", "status": "Passed",
                     "details": "MFA authentication events are monitored and logged."},
                ],
            },
            {
                "name": "Application Security",
                "checks": [
                    {"name": "Conduct regular security code reviews", "status": "Passed",
                     "details": "Regular security code reviews are conducted for applications."},
                    {"name": "Implement Web Application Firewall (WAF) for web apps", "status": "Failed",
                     "details": "Web Application Firewall (WAF) is not implemented for web apps."},
                    {"name": "Perform penetration testing on critical applications", "status": "Passed",
                     "details": "Penetration testing is performed on critical applications."},
                ],
            },
            # Add more real benchmarks here
        ],
    }
    return dummy_benchmarks

# Endpoint to run ZAP spider on a target
@app.get("/run-scanner")
def run_spider(your_target: str):
    scan_id = zap.spider.scan(your_target)
    wait_for_spider_completion(scan_id)

    try:
        spider_results = zap.spider.results(scan_id)
    except ValueError as e:
        print("Error:", e)
        spider_results = "No spider results available"

    return {"spider_results": spider_results}


# Endpoint to get ZAP scan information and alerts
@app.get("/get-info")
def get_details():
    while int(zap.pscan.records_to_scan) > 0:
        print('Records to passive scan:', zap.pscan.records_to_scan)
        time.sleep(2)

    print('Passive scan completed')
    hosts = ', '.join(zap.core.hosts)
    print('Hosts:', hosts)

    alerts = zap.core.alerts()
    print('Alerts:')
    pprint(alerts)

    return {"message": "Scan completed", "hosts": hosts, "alerts": alerts}


# Endpoint to retrieve and filter ZAP alerts
@app.get("/alerts")
async def get_alerts():
    st = 0
    pg = 5000
    alert_count = 0
    blacklist = [1, 2]
    while True:
        alerts = zap.alert.alerts(baseurl=target, start=st, count=pg)
        if not alerts:
            break
        print('Reading ' + str(pg) + ' alerts from ' + str(st))
        alert_count += len(alerts)
        for alert in alerts:
            plugin_id = alert.get('pluginId')
            if plugin_id in blacklist:
                continue
            if alert.get('risk') == 'High':
                continue
            if alert.get('risk') == 'Informational':
                continue
        st += pg

    print('Total number of alerts:', alert_count)
    return {"alert_count": alert_count}


# Endpoint to perform network scanning using Nmap
@app.get("/net-scan")
def target_network(enter_addr: str):
    # Nmap setup
    nmap_path = [r"C:\Program Files (x86)\Nmap\nmap.exe"]
    target_ip = enter_addr
    nm = nmap.PortScanner(nmap_search_path=nmap_path)
    nm.scan(target_ip, '10-20')

    # Gather scan results
    info = nm.scaninfo()
    host_info = nm[target_ip].hostname()
    current_state = nm[target_ip].state()
    protocols = nm[target_ip].all_protocols()

    result = {
        "network_info": info,
        "host": host_info,
        "service_status": current_state,
        "protocols": protocols,
        "ports": {}
    }

    # Collect port information
    for host in nm.all_hosts():
        result["ports"][host] = {}
        for proto in nm[host].all_protocols():
            result["ports"][host][proto] = []
            for port in nm[host][proto].keys():
                port_info = nm[host][proto][port]
                result["ports"][host][proto].append(
                    {"port": port, "state": port_info["state"]}
                )

    return result


# Endpoint to perform network status scanning using Nmap
@app.get("/net-work-status")
def net_stat(enter_addr: str):
    # Nmap setup
    nmap_path = [r"C:\Program Files (x86)\Nmap\nmap.exe"]
    nm = nmap.PortScanner(nmap_search_path=nmap_path)
    nm.scan(hosts=enter_addr, arguments='-n -sP -PE -PA21,23,80,3389')

    # Gather hosts' status information
    hosts_list = [(x, nm[x]['status']['state']) for x in nm.all_hosts()]
    for host, status in hosts_list:
        print(f'{host}:{status}')

    return {"hosts": hosts_list}

#################### cis #############################################
######################################################################


# Endpoint to get website benchmarks
@app.get("/website-benchmarks")
def website_benchmarks(website_url: str = Query(..., description="Enter the website URL")):
    benchmarks = get_website_benchmarks(website_url)
    return benchmarks

# Run the FastAPI app
if __name__ == "__main__":
    import uvicorn

    uvicorn.run(app, host="0.0.0.0", port=8000)
