import Log from "../models/log-model.js";
import User from "../models/user-model.js";
import { createToken } from "../utils/create-token.js";
import { hashData, verifyHashedData } from "../utils/hash-data.js";

export const authenticateUser = async (data) => {
  try {
    const { email, password, device, logTime } = data;
    const fetchedUser = await User.findOne({
      email,
    });

    if (!fetchedUser) {
      throw Error("Invalid credentials entered!");
    }

    const hashedPassword = fetchedUser.password;
    const passwordMatch = await verifyHashedData(password, hashedPassword);

    if (!passwordMatch) {
      throw new Error("Invalid password entered!");
    }

    // create user token
    const tokenData = { userId: fetchedUser._id, email };
    const token = await createToken(tokenData);
    // assign user token
    fetchedUser.token = token;

    const newLog = new Log({
      userId: fetchedUser._id,
      device,
      logTime,
      username: fetchedUser.username,
    });
    fetchedUser.device = device;
    fetchedUser.logTime = logTime;
    console.log({ logTime });
    await newLog.save();
    console.log({ logTime });
    return fetchedUser;
  } catch (error) {
    throw error; // Rethrow the error to be caught by the calling function
  }
};

export const createNewUser = async (data) => {
  try {
    const { name, email, password, username } = data;
    console.log({ email });

    const existingUser = await User.findOne({ email });

    if (existingUser) {
      throw Error("User with provided email already exists");
    }

    const hashedPassword = await hashData(password);
    const newUser = new User({
      name,
      email,
      password: hashedPassword,
      username,
    });

    console.log({ newUser });
    const createdUser = await newUser.save(); // fixed typo "ceratedUser" to "createdUser"
    console.log({ createdUser });
    return createdUser;
  } catch (error) {
    console.log(error);
    throw error; // re-throw the error to be handled by the calling code
  }
};

// face id change status

export const faceidChangeStatus = async (data) => {
  try {
    const { userid, isFaceid } = data;
    console.log({ userid });

    const user = await User.findByIdAndUpdate(
      userid,
      { isFaceid },
      { new: true }
    );

    return user;
  } catch (error) {
    throw error;
  }
};

export const updateProfile = async (userId, data) => {
  try {
    console.log({ data });
    // Define the fields that are allowed to be updated
    const allowedFields = {
      location: {
        long: data.location.long,
        lang: data.location.lang,
      },
      companyId: data.companyId,
      device: data.device,
      shift: data.shift,
      isVerified: data.isVerified,
      companyid: data.companyid,
      isFaceid: data.isFaceid,
      timeShift: data.timeShift,
      name : data.name,
      username: data.username,

    };

    // Find the user by their ID
    const user = await User.findById(userId);
    console.log({ user });

    if (!user) {
      throw Error("User not found");
    }

    // Update the allowed fields
    Object.assign(user, allowedFields);

    // Save the updated user profile
    const updatedUser = await user.save();

    return updatedUser;
  } catch (error) {
    console.log(error);
    throw error;
  }
};

export const usernameNameUpdate = async (userId, data) => {

  try{

   const allowedFields = {
      username: data.username,
      name : data.name,
      shift: data.shift,
      timeShift: data.shift,
   }

   const user = await User.findById(userId);
    console.log({ user });

    if (!user) {
      throw Error("User not found");
    }

    Object.assign(user, allowedFields);

    const updatedUser = await user.save();

    return updatedUser;



  }catch{

  }

}

export const getUserById = async (userId) => {
  try {
    const user = await User.findById(userId); // Use the User model to find a user by ID

    if (!user) {
      throw new Error("User not found"); // Handle the case where the user is not found
    }

    return user; // Return the user details
  } catch (error) {
    console.error("Error fetching user by ID:", error);
    throw error; // Rethrow the error for handling it elsewhere
  }
};
