import { Router } from "express";
import {
  createCompanybasic,
  createContactInformation,
  createTechnicalInformation,
  getCompanyById,
  getVulnerabilities,
  getVulnerabilitiesByLastSevenDays,
  getVulnerabilitiesForSpecificDay,
} from "../controllers/company-controller.js";
import rateLimit from "express-rate-limit";
const router = Router();

router.post("/createcompanybasic/:id", async (req, res) => {
  try {
    const {
      appicationURL,
      applicationName,
      ipAddress,
      applicationDescription,
    } = req.body;

    const createdCompany = await createCompanybasic({
      appicationURL,
      applicationName,
      ipAddress,
      applicationDescription,
      userid: req.params.id,
    });

    res.status(200).json(createdCompany);
  } catch (error) {
    res.status(400).json(error.message);
  }
});

router.post("/technicalinformation", async (req, res) => {
  try {
    const {
      financialvalue,
      frontend,
      backend,
      database,
      application,
      others,
      webAppType,
      companyid,
    } = req.body;
    const createCompany = await createTechnicalInformation({
      financialvalue,
      frontend,
      backend,
      database,
      application,
      others,
      webAppType,
      companyid,
    });
    res.status(200).json(createCompany);
  } catch (error) {
    res.status(400).json(error.message);
  }
});

router.post("/contactinformation", async (req, res) => {
  try {
    const { companyName, contactNumber, address, companyid, userid } = req.body;
    const createCompany = await createContactInformation({
      companyName,
      contactNumber,
      address,
      companyid,
    });
    res.status(200).json(createCompany);
  } catch (error) {
    res.status(400).json(error.message);
  }
});

router.get("/companies/:id", async (req, res) => {
  const companyId = req.params.id;

  try {
    const company = await getCompanyById(companyId);

    if (!company) {
      return res.status(404).json({ error: "Company not found" });
    }

    res.json(company);
  } catch (error) {
    console.error(error);
    res.status(500).json({ error: "Internal Server Error" });
  }
});

//vulnurabilities scanner

router.post("/vulnurabilities/:id", async (req, res) => {
  try {
    const companyId = req.params.id;
    const createCompany = await getVulnerabilities(
      companyId,
    );
    res.status(200).json(createCompany);
  } catch (error) {
    res.status(400).json(error.message);
  }
});

router.post("/vulnurabilitiesbyweek/:id", async (req, res) => {
  try {
    const companyId = req.params.id;
    const createCompany = await getVulnerabilitiesByLastSevenDays(
      companyId,
    );
    res.status(200).json(createCompany);
  } catch (error) {
    res.status(400).json(error.message);
  }
});

const limiter = rateLimit({
  windowMs: 60 * 200, // 15 minutes
  max: 100, // Max requests per windowMs
  message: 'Too many requests from this IP, please try again later.',
});

router.post("/vulnurabilitiesbyday/:id",limiter, async (req, res) => {
  try {
    const companyId = req.params.id;
    const createCompany = await getVulnerabilitiesForSpecificDay(
      companyId,
    );
    res.status(200).json(createCompany);
  } catch (error) {
    res.status(400).json(error.message);
  }
});

export { router as companyRouter };
