import { Router } from "express";
import {
  authenticateUser,
  createNewUser,
  faceidChangeStatus,
  getUserById,
  updateProfile,
  usernameNameUpdate,
} from "../controllers/user-controller.js";
import { verifyToken } from "../middleware/auth.js";

const router = Router();

router.post("/signup", async (req, res) => {
  let { name, email, password, username } = req.body;

  name = name.trim();
  email = email.trim();
  password = password.trim();
  username = username.trim();

  try {
    if (!(name && email && password)) {
      throw Error("Empty Inputs Feilds");
    } else if (!/^[a-zA-Z ]*$/.test(name)) {
      throw Error("Invalid name enterd");
    } else if (!/^[\w-\.]+@([\w-]+\.)+[\w-]{2,4}$/.test(email)) {
      throw Error("Invalid email enterd");
    } else {
      const newUser = await createNewUser({
        name,
        email,
        password,
        username,
      });
      res.status(200).json(newUser);
    }
  } catch (error) {
    res.status(400).json(error.message);
  }
});

router.post("/", async (req, res) => {
  try {
    let { email, password, device, logTime } = req.body;
    email = email.trim();
    password = password.trim();
    if (!(email && password)) {
      throw new Error("Empty credentials supplied!"); // Create an Error object
    }

    const authenticatedUserss = await authenticateUser({
      email,
      password,
      device,
      logTime,
    });
    res.status(200).json(authenticatedUserss);
  } catch (error) {
    console.log({ error });
    res.status(400).json({ error: error.message }); // Send the error message as JSON
  }
});

// protected route
router.get("/private_data", verifyToken, (req, res) => {
  res
    .status(200)
    .send("Youre in the private territory of ${req.currentUser.email}");
});

router.post("/isfaceid", async (req, res) => {
  try {
    const { userid, isFaceid } = req.body;

    console.log({ userid, isFaceid });

    // Call the faceidChangeStatus function to update the user's isFaceid status
    const updatedUser = await faceidChangeStatus({ userid, isFaceid });
    console.log({ updatedUser });
    // Return the updated user
    res.json(updatedUser);
  } catch (error) {
    // Handle errors appropriately, e.g., send an error response
    res.status(500).json({ error });
  }
});

router.put("/profile/:userId", async (req, res) => {
  const userId = req.params.userId;
  const data = req.body;

  try {
    // Ensure that the user exists
    // const existingUser = await User.findById(userId);
    // console.log({existingUser})
    // if (!existingUser) {
    //   throw Error("User not found");

    // }

    // Call the updateProfile function to update the user's profile
    const updatedUser = await updateProfile(userId, data);

    res.status(200).json(updatedUser);
  } catch (error) {
    res.status(400).json({ error: error.message });
  }
});

router.put("/profileonlyusernameandname/:userId", async (req, res) => {
  const userId = req.params.userId;
  const data = req.body;

  try {
    // Ensure that the user exists
    // const existingUser = await User.findById(userId);
    // console.log({existingUser})
    // if (!existingUser) {
    //   throw Error("User not found");

    // }

    // Call the updateProfile function to update the user's profile
    const updatedUser = await usernameNameUpdate(userId, data);

    res.status(200).json(updatedUser);
  } catch (error) {
    res.status(400).json({ error: error.message });
  }
});

router.get("/getuserdetails/:id", async (req, res) => {
  try {
    const userDetails = await getUserById(req.params.id);
    res.status(200).json(userDetails);
  } catch (error) {
    res.status(400).json({ error: error.message });
  }
});

export { router as userRouter };
