//import npm packages
import express from "express";
import cors from "cors";

import dotenv from "dotenv";
import ConnectDB from "./db/database.js";
import bodyParser from "body-parser";
import { userRouter } from "./routes/user-route.js";
import { otpRouter } from "./routes/otp-route.js";
import { companyRouter } from "./routes/company-route.js";

//configs
const app = express();
app.use(express.json());
app.use(bodyParser.json())
app.use(cors());
dotenv.config();

//server connection
app.use((err, req, res, next) => {
  const errorStatus = err.status || 500;
  const errorMessage = err.message || "Somthing went Wrong";
  return res.status(errorStatus).json({
    success: false,
    status: errorStatus,
    message: errorMessage,
    stack: err.stack,
  });
});

//port define
const port = process.env.PORT || 5000;

// port listen
app.listen(port, () => {
  console.log(`Example app listening on port ${port}`);
});

app.use('/api/v1/user', userRouter);
app.use('/api/v1/otp', otpRouter);
app.use('/api/v1/company', companyRouter);

ConnectDB();

export default app;
