"use client";

import {
  createContext,
  useContext,
  Dispatch,
  SetStateAction,
  useState,
  ReactNode,
} from "react";

interface TechData {
  value: string;
  frontend: string;
  backend: string;
  database: string;
  application: string;
  others: string;
  webAppType: string;
  [key: string]: string; // Index signature for any string key
}

interface QuizResults {
  expectedAnswer: string;
  marks: number;
  question: string;
  recommendation: string;
  status: string;
  userAnswer: string;
}

interface ContextProps {
  name: string;
  setName: Dispatch<SetStateAction<string>>;
  username: string;
  setUsername: Dispatch<SetStateAction<string>>;
  email: string;
  setEmail: Dispatch<SetStateAction<string>>;
  password: string;
  setPassword: Dispatch<SetStateAction<string>>;
  terms: boolean;
  setTerms: Dispatch<SetStateAction<boolean>>;
  techData: TechData;
  setTechData: (newTechData: TechData) => void;
  quizResults: QuizResults[];
  setQuizResults: Dispatch<SetStateAction<QuizResults[]>>;
  activeItem: string;
  setActiveItem: Dispatch<SetStateAction<string>>;
  netdata: any[];
  setNetData: React.Dispatch<React.SetStateAction<any[]>>;
}

const GlobalContext = createContext<ContextProps>({
  name: "",
  setName: (): string => "",
  username: "",
  setUsername: (): string => "",
  email: "",
  setEmail: (): string => "",
  password: "",
  setPassword: (): string => "",
  terms: false,
  setTerms: (): boolean => false,
  techData: {
    value: "",
    frontend: "",
    backend: "",
    database: "",
    application: "",
    others: "",
    webAppType: "",
  },
  setTechData: (newTechData: TechData) => {},
  quizResults: [],
  setQuizResults: (): QuizResults[] => [],
  activeItem: "",
  setActiveItem: (): string => "",
  netdata: [],
  setNetData: () => {},
});

export const GlobalContextProvider = ({
  children,
}: {
  children: ReactNode;
}) => {
  const [name, setName] = useState("");
  const [username, setUsername] = useState("");
  const [email, setEmail] = useState("");
  const [password, setPassword] = useState("");
  const [terms, setTerms] = useState(false);
  const [techData, setTechData] = useState<TechData>({
    value: "",
    frontend: "",
    backend: "",
    database: "",
    application: "",
    others: "",
    webAppType: "",
  });
  const [activeItem, setActiveItem] = useState("");
  const [quizResults, setQuizResults] = useState<QuizResults[]>([]);
  const [netdata, setNetData] = useState<any[]>([]);

  return (
    <GlobalContext.Provider
      value={{
        name,
        setName,
        username,
        setUsername,
        email,
        setEmail,
        password,
        setPassword,
        terms,
        setTerms,
        techData,
        setTechData,
        quizResults,
        setQuizResults,
        activeItem,
        setActiveItem,
        netdata,
        setNetData,
      }}
    >
      {children}
    </GlobalContext.Provider>
  );
};

export const useGlobalContext = () => useContext(GlobalContext);
