"use client";

import { useGlobalContext } from "@/app/Context/store";
import axios from "axios";
import Image from "next/image";
import { useRouter } from "next/navigation";
import { useEffect, useState } from "react";

export default function Navigation() {
  const router = useRouter();

  const [appStatus, setAppStatus] = useState("");
  const [loadingStatus, setLoadingStatus] = useState(true);
  const { activeItem, setActiveItem } = useGlobalContext();

  useEffect(() => {
     handleLogout();
    handleAppStatus();
  }, []);

  const handleAppStatus = async () => {
    const response = await axios.get("http://localhost:8000/net-work-status", {
      params: {
        enter_addr: localStorage.getItem("ipAddress"),
      },
      headers: {
        accept: "application/json",
      },
    });
    setLoadingStatus(false);
    setAppStatus(response.data.hosts[0][1]);
    console.log(response.data.hosts[0][1]);
  };

  // check if the user is logged in or not using local storage
  const handleLogout = () => {
    if (localStorage.getItem("userid") === null) {
      router.push("/auth/login");
    } else {
      null;
    }
  };

  // Function to conditionally render the active item

  if (activeItem === "vulnerability") {
    router.push("/dashboard/vulnerability");
  } else if (activeItem === "risk") {
    router.push("/dashboard/risk");
  } else if (activeItem === "tools") {
    router.push("/dashboard/tools");
  } else if (activeItem === "profile") {
    router.push("/dashboard/profile");
  }

  return (
    <div className="flex flex-col sm:flex-row w-full mb-10">
      {/* Logo */}
      <div className="flex flex-grow justify-center items-center sm:justify-start pr-10">
        <Image
          src="/images/customerOnboarding/webguardin-logo.png"
          width={250}
          height={150}
          alt="logo"
          className="ml-10"
        />
        {loadingStatus ? (
          // loaading animation
          <div className="flex flex-row justify-center items-center ml-10">
            <div className="animate-spin rounded-full h-10 w-10 border-t-2 border-b-2 border-purple-500"></div>
          </div>
        ) : (
          // app status
          <div className="flex flex-row justify-center items-center ml-10">
            <p className="text-sm sm:text-2xl font-semibold text-[#B200B6]">
              App Status :{" "}
            </p>
            {/* app status with emoji */}
            {appStatus === "up" ? (
              <p className="text-sm sm:text-2xl font-semibold text-[#00FF00]">
                {" "}
                UP ⬆️
              </p>
            ) : (
              <p className="text-sm sm:text-2xl font-semibold text-[#FF0000]">
                {" "}
                DOWN ⬇️
              </p>
            )}
          </div>
        )}
      </div>

      {/* Navigation items */}
      <div className="flex flex-row justify-center align-middle items-center px-5 sm:px-10 bg-[#FEDDFF] rounded-lg sm:rounded-bl-3xl">
        {/* Vulnerability Dashboard item */}
        <p
          onClick={() => setActiveItem("vulnerability")}
          className={`mr-10 font-semibold text-sm sm:text-2xl ${
            activeItem === "vulnerability" ? "text-[#ee39f1]" : "text-[#B200B6]"
          } hover:text-[#db33de] cursor-pointer`}
        >
          VULNERABILITY
        </p>

        {/* Risk Dashboard item */}
        <p
          onClick={() => setActiveItem("risk")}
          className={`mr-10 font-semibold text-sm sm:text-2xl ${
            activeItem === "risk" ? "text-[#ee39f1]" : "text-[#B200B6]"
          } hover:text-[#db33de] cursor-pointer`}
        >
          RISK
        </p>
        {/* Tools */}
        <p
          onClick={() => setActiveItem("tools")}
          className={`mr-10 font-semibold text-sm sm:text-2xl ${
            activeItem === "tools" ? "text-[#ee39f1]" : "text-[#B200B6]"
          } hover:text-[#db33de] cursor-pointer`}
        >
          TOOLS
        </p>

        {/* Profile item */}
        <p
          onClick={() => setActiveItem("profile")}
          className={`mr-10 font-semibold text-sm sm:text-2xl ${
            activeItem === "profile" ? "text-[#ee39f1]" : "text-[#B200B6]"
          } hover:text-[#db33de] cursor-pointer`}
        >
          PROFILE
        </p>
      </div>
    </div>
  );
}
