"use client";
import { useState } from "react";
import { useRouter } from "next/navigation";
import Navbar from "../../components/navbar/page";
import { useGlobalContext } from "@/app/Context/store";
import Link from "next/link";

export default function Rasp() {
  const router = useRouter();
  const { quizResults, setQuizResults } = useGlobalContext();

  // Define your data array with questions, expected answers, and marks
  const data: any = [
    {
      Question: "Does the web application have a documented security policy?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "A documented security policy is the cornerstone of a robust security posture. Assemble a cross-functional team, including security experts and key stakeholders, to create a comprehensive security policy tailored to your organization's needs. Cover aspects such as data classification, access controls, incident response procedures, and compliance requirements. Ensure that the policy is effectively communicated to all relevant personnel and integrated into employee training programs. Regularly review and update the policy to reflect changes in the threat landscape and organizational needs.",
    },
    {
      Question:
        "Is there an inventory of all assets and data associated with the web application?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Start by conducting a thorough assessment of all assets and data associated with the web application. Develop and maintain an asset inventory that includes hardware, software, data stores, and third-party services. For data, classify and label information based on its sensitivity and importance. Implement a system to track changes and updates to the inventory to ensure it remains accurate over time. This inventory is vital for risk assessments, vulnerability management, and incident response.",
    },
    {
      Question: "Are security roles and responsibilities clearly defined?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Clearly defined security roles and responsibilities are essential for accountability and efficiency. Identify key security roles, such as security administrators, incident responders, and access approvers. Document the responsibilities and access privileges associated with each role. Ensure that this information is readily available to all relevant personnel. Regularly review and update these roles as organizational requirements evolve. Training and awareness programs should emphasize the importance of each role in maintaining security.",
    },
    {
      Question:
        "Is there a process for regularly patching and updating the application's software components?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Establishing a robust patch management process is critical for addressing vulnerabilities promptly. Begin by identifying all software components and dependencies used in the web application. Develop a patching schedule and prioritize updates based on severity. Implement automated tools for vulnerability scanning and tracking patches. Test patches in a controlled environment before deploying them in the production environment to avoid unexpected issues. Document the patching process, assign responsibility, and ensure timely updates.",
    },
    {
      Question:
        "Is multi-factor authentication (MFA) implemented for privileged accounts?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Implementing MFA for privileged accounts is a critical security control. Select a reliable MFA solution compatible with your authentication system. Configure MFA for all privileged accounts, such as administrators and those with access to sensitive data. Communicate the MFA requirement to users and provide guidance on setting up and using MFA effectively. Regularly monitor MFA compliance for privileged accounts to ensure its consistent use.",
    },
    {
      Question: "Is there a Web Application Firewall (WAF) in place?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Implementing a Web Application Firewall (WAF) is crucial for protecting against common web application vulnerabilities. Evaluate and select a suitable WAF solution for your web application. Configure the WAF to filter and block malicious traffic, including SQL injection, cross-site scripting (XSS), and other attacks. Regularly update and tune the WAF rules to adapt to evolving threats. Monitor WAF logs and alerts to identify and respond to potential threats in real-time.",
    },
    {
      Question:
        "Are security headers (e.g., Content Security Policy) properly configured?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Properly configuring security headers is essential for mitigating various web application vulnerabilities. Implement security headers such as Content Security Policy (CSP), HTTP Strict Transport Security (HSTS), and X-Content-Type-Options. Customize these headers to fit the specific requirements of your web application. Regularly test and review your security headers to ensure they effectively prevent common attacks, such as XSS and content spoofing.",
    },
    {
      Question:
        "Is data encryption used for sensitive data in transit (e.g., HTTPS)?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Implementing data encryption for sensitive data in transit is a fundamental security practice. Ensure that your web application enforces the use of HTTPS for all data transmission. Obtain and regularly renew SSL/TLS certificates from reputable Certificate Authorities (CAs). Configure your web server and application to use strong encryption algorithms and protocols. Periodically test your encryption implementation to identify and address vulnerabilities or misconfigurations.",
    },
    {
      Question:
        "Are security logs enabled, regularly reviewed, and retained for an appropriate period?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Logging is crucial for detecting and responding to security incidents. Ensure that security logs are enabled and capture relevant events, including login attempts, access control changes, and potential security breaches. Establish a regular log review process to identify anomalies or suspicious activities. Define log retention policies that comply with regulatory requirements and ensure logs are stored securely to prevent tampering. Implement automated log analysis tools to enhance the effectiveness of log review.",
    },
    {
      Question: "Is there a process for vulnerability scanning and assessment?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Regular vulnerability scanning and assessment are essential for identifying and addressing security weaknesses. Invest in reputable vulnerability scanning tools and services. Establish a structured process to conduct regular scans of your web application and associated infrastructure. Prioritize and remediate vulnerabilities based on their severity and potential impact. Perform in-depth assessments, including manual testing and code review, to uncover complex vulnerabilities that automated scanners may miss. Continuously monitor for new vulnerabilities and incorporate them into your assessment process.",
    },
    {
      Question:
        "Are regular penetration tests conducted on the web application?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Regular penetration testing is a critical step in assessing the resilience of your web application to real-world attacks. Engage experienced penetration testers or ethical hackers to conduct comprehensive tests. Include both automated and manual testing approaches to identify vulnerabilities, misconfigurations, and logic flaws. Ensure that the testing scope covers all critical components of the application. Act on the findings by addressing identified vulnerabilities and conducting follow-up tests to verify remediation efforts.",
    },
    {
      Question: "Are security incidents and breaches reported and documented?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Establish a clear process for reporting and documenting security incidents and breaches. Ensure that all personnel understand their responsibility to report any security-related issues promptly. Develop an incident response plan that outlines the steps to take when a security incident is detected. Document all incidents, including their nature, impact, and actions taken, in a centralized incident database. Regularly review and analyze incident data to identify trends and areas for improvement in your security posture.",
    },
    {
      Question:
        "Is there a process for handling security incidents and breaches?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Having a well-defined process for handling security incidents and breaches is crucial for minimizing the impact of security events. Develop and document an incident response plan that outlines roles and responsibilities, communication procedures, escalation paths, and containment and recovery strategies. Ensure that your incident response team is trained and prepared to execute the plan effectively. Regularly review and update the plan to account for evolving threats and lessons learned from past incidents.",
    },
    {
      Question: "Are security updates and patches tested before deployment?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Establish a structured process for testing security updates and patches before deploying them to your production environment. Create a staging or test environment that closely mirrors your production setup. Test each update or patch in this environment to ensure it does not introduce new issues or conflicts with existing components. Develop test cases that cover common scenarios and potential vulnerabilities. Document the testing results and validate that the updates work as expected before applying them in production.",
    },
    {
      Question:
        "Is there a process for secure code review and development practices?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Secure code review and development practices are essential for preventing vulnerabilities at the source. Implement secure coding guidelines and standards within your development team. Establish a formal code review process that includes security-focused reviews. Train your developers in secure coding practices and provide them with tools for static and dynamic code analysis. Conduct periodic code reviews to identify and remediate vulnerabilities and security flaws in the application code. Continuously update and improve your coding practices based on lessons learned from code reviews and industry trends.",
    },
    {
      Question: "Are user access controls implemented effectively?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Effective user access controls are essential for preventing unauthorized access to sensitive data and functionalities. Review and refine your access control policies and procedures to ensure they align with the principle of least privilege. Implement strong authentication mechanisms, such as password policies, user account lockout, and account recovery processes. Regularly audit user access rights and permissions to identify and revoke unnecessary privileges. Monitor user activities and set up alerts for suspicious or unauthorized access attempts.",
    },
    {
      Question:
        "Are error messages configured to not reveal sensitive information?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Configuring error messages to prevent the exposure of sensitive information is crucial for protecting your web application from attackers. Ensure that error messages do not disclose sensitive data such as database errors, internal system details, or user-specific information. Develop custom error messages that provide minimal information to users while logging detailed error information securely for system administrators. Regularly review and test error handling to ensure it aligns with security best practices.",
    },
    {
      Question:
        "Is session management implemented securely (e.g., session timeout)?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Secure session management is vital for protecting user sessions from attacks like session fixation and session hijacking. Implement session timeouts to automatically log users out after a period of inactivity. Use secure cookies to store session identifiers and ensure they are encrypted and tamper-resistant. Regenerate session identifiers after authentication to prevent session fixation. Validate and sanitize session data to protect against session-based attacks. Regularly review and test your session management implementation to identify and mitigate vulnerabilities.",
    },
    {
      Question:
        "Is there a process for managing and reviewing third-party components and libraries?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Managing third-party components and libraries is crucial for maintaining the security of your web application. Create and maintain an inventory of all third-party components and libraries used, including their versions and sources. Subscribe to security advisories for these components to receive timely updates on vulnerabilities. Establish a process for reviewing and assessing the security of third-party code before integration. Monitor for updates and patches to third-party components and apply them promptly to address known vulnerabilities.",
    },
    {
      Question:
        "Is the web application compliant with relevant regulatory standards (e.g., GDPR, HIPAA)?",
      "Expected Answer": "Yes",
      Marks: 5,
      Recommendation:
        "Compliance with relevant regulatory standards is essential to protect user data and maintain legal and ethical standards. Identify the specific regulatory requirements that apply to your organization and web application, such as GDPR, HIPAA, or industry-specific standards. Conduct a thorough assessment to ensure compliance with these standards, including data handling, user consent, and security measures. Establish processes for ongoing compliance monitoring, reporting, and documentation. Engage legal and compliance experts to ensure that your web application aligns with the latest regulatory guidelines.",
    },
    // ... (repeat for other objects in the array)
  ];

  // Initialize the state to store user answers and question status
  const [userAnswers, setUserAnswers] = useState<string[]>(
    Array(data.length).fill("Yes")
  );
  const [questionStatus, setQuestionStatus] = useState<string[]>(
    Array(data.length).fill("unanswered") // Initialize with "unanswered"
  );

  // Function to handle changes in user answers
  const handleAnswerChange = (index: number, answer: string) => {
    const updatedAnswers = [...userAnswers];
    updatedAnswers[index] = answer;
    setUserAnswers(updatedAnswers);
  };

  // Function to generate the result array
  const generateResultArray = () => {
    const resultArray = data.map((question: any, index: any) => {
      return {
        question: question.Question,
        expectedAnswer: question["Expected Answer"],
        userAnswer: userAnswers[index],
        status:
          userAnswers[index] === question["Expected Answer"]
            ? "right"
            : "wrong",
        marks: question.Marks,
        recommendation: question.Recommendation,
      };
    });
    return resultArray;
  };

  // Calculate the score
  const calculateScore = () => {
    let score = 0;
    for (let i = 0; i < data.length; i++) {
      if (userAnswers[i] === data[i]["Expected Answer"]) {
        score += data[i].Marks;
      }
    }
    return score;
  };

  const handleResultRouter = () => {
    const score = calculateScore();
    console.log("Your score:", score);

    // Generate the result array
    const resultArray = generateResultArray();
    setQuizResults(resultArray);

    // Log the generated result array to the console
    console.log("Result Array:", resultArray);

    // Navigate to the result page with the result array
    router.push(`/dashboard/tools/manual/result`);
  };

  return (
    <div className="m-10">
      <Navbar />

      <div className="flex flex-row mb-5">
        <Link href={"http://localhost:3000/dashboard/"}><p className="text-[#B200B6]"> Home  </p></Link>
        <p>{` / Manual Compliance Check`}</p>
      </div>

      <h1 className="px-10 py-2 mb-5 text-xl font-semibold bg-[#ff3e3e] text-white rounded-full w-fit">
        MANUAL COMPLIANCE CHECK
      </h1>

      <div className="flex flex-col bg-[#eaeaea] pb-5 rounded-3xl">
        {data.map((question: any, index: any) => (
          <div
            key={index}
            className="flex flex-col p-5 ml-5 mr-5 mt-5 bg-white rounded-xl"
          >
            <div className="flex flex-row justify-between items-center">
              <h1 className="text-xl font-semibold">{`${index + 1}. ${
                question.Question
              }`}</h1>
              <div className="flex flex-row justify-between items-center">
                <h1 className="mr-5">Answer</h1>
                <select
                  className="px-2 py-1 bg-[#eaeaea] rounded-lg"
                  value={userAnswers[index]}
                  onChange={(e) => handleAnswerChange(index, e.target.value)}
                >
                  <option value="Yes">Yes</option>
                  <option value="No">No</option>
                </select>
              </div>
            </div>
          </div>
        ))}
        <button
          className="bg-[#ff3e3e] hover-bg-[#bb1d1d] text-white rounded-full w-fit py-2 px-4 mt-5 ml-5"
          onClick={handleResultRouter}
        >
          SUBMIT THE QUIZ
        </button>
      </div>
    </div>
  );
}
