"use client";

import { useGlobalContext } from "@/app/Context/store";
import Navbar from "@/app/dashboard/components/navbar/page";
import Link from "next/link";
import { useRouter } from "next/navigation";
import { useState } from "react";

export default function Result() {
  const router = useRouter();

  const handleManualRouter = () => {
    router.push("/dashboard/tools/manual");
  };

  const { quizResults, setQuizResults } = useGlobalContext();
  console.log({ quizResults });

  const totalMarks = quizResults.reduce((acc, result) => {
    if (result.status === "right") {
      return acc + result.marks;
    }
    return acc;
  }, 0);

  // Calculate the percentage of the total marks obtained
  const percentage = (totalMarks / 100) * 100;

  // Set the percentage in a state variable
  const [percentageObtained, setPercentageObtained] = useState(percentage);

  console.log({ percentageObtained });

  return (
    <div className="m-10">
      <Navbar />
      <div className="flex flex-row mb-5">
        <Link href={"http://localhost:3000/dashboard/"}><p className="text-[#B200B6]"> Home  / </p></Link>
        <Link href={"http://localhost:3000/dashboard/tools/manual"}><p className="text-[#B200B6]"> Quiz /  </p></Link>
        <p>{`  Manual Compliance Check`}</p>
      </div>
      <h1 className="px-10 py-2 mb-5 text-xl font-semibold bg-[#ff3e3e] text-white rounded-full w-fit">
        MANUAL COMPLIANCE CHECK RESULT
      </h1>
      <div className="flex flex-col justify-center items-center">
        <div className="flex flex-row justify-center items-center">
          <p className="text-3xl">YOUR SCORE </p>
          <p className="ml-5 font-black text-5xl">
            {percentageObtained ? percentageObtained+"%" : ""}
          </p>
        </div>

        <p className="text-center mx-96 mt-5 text-lg mb-10">
          Based on the answers you provided. Above are the marks your obtain.
          Please read the recommendations in below attached result sheet and
          comply with them. After that you can retake the quiz to obtain full
          marks and fully secure your web application.
        </p>

        {/* {
        quizResults?.map((result, index) => (
          <>
          
          
          </>
        ))
       } */}

        {/* result sheet for the quiz questions and right or wrong in a table*/}
        <div className="flex flex-col bg-[#eaeaea] pb-5 rounded-3xl w-full">
          {/* QUIZ option with a dropdown answers */}
          {/* <div className="flex flex-col p-5 ml-5 mr-5 mt-5 bg-white rounded-xl">
            <div className="flex flex-row justify-between items-center">
              <h1 className="text-xl font-semibold">1. Question 1</h1>
              <div className="flex flex-row justify-between items-center">
                <h1 className="mr-5">✅ Answer</h1>
                <select className="px-2 py-1 bg-[#eaeaea] rounded-lg">
                  <option>Yes</option>
                  <option>No</option>
                </select>
              </div>
            </div>
          </div>

          <div className="flex flex-col p-5 ml-5 mr-5 mt-5 bg-white rounded-xl">
            <div className="flex flex-row justify-between items-center">
              <h1 className="text-xl font-semibold">1. Question 1</h1>
              <div className="flex flex-row justify-between items-center">
                <h1 className="mr-5">❌ Answer</h1>
                <select className="px-2 py-1 bg-[#eaeaea] rounded-lg">
                  <option>Yes</option>
                  <option>No</option>
                </select>
              </div>
            </div>
          </div> */}

          {/* <div className="flex flex-col p-5 ml-5 mr-5 mt-5 bg-white rounded-xl">
            <div className="flex flex-row justify-between items-center">
              <h1 className="text-xl font-semibold">1. Question 1</h1>
              <div className="flex flex-row justify-between items-center">
                <h1 className="mr-5">❌ Answer</h1>
                <select className="px-2 py-1 bg-[#eaeaea] rounded-lg">
                  <option>Yes</option>
                  <option>No</option>
                </select>
              </div>
            </div>
          </div> */}

          <div className="flex flex-col bg-[#eaeaea] pb-5 rounded-3xl w-full">
            {quizResults?.map((result, index) => (
              <div
                className="flex flex-col p-5 ml-5 mr-5 mt-5 bg-white rounded-xl"
                key={index}
              >
                <div className="flex flex-row justify-between items-center">
                  <h1 className="text-xl font-semibold">{`${index + 1}. ${
                    result.question
                  }`}</h1>
                  <div className="flex flex-row justify-between items-center">
                    <h1
                      className={`mr-5 ${
                        result.status === "right"
                          ? "text-green-500"
                          : "text-red-500"
                      }`}
                    >
                      {result.status === "right" ? "✅ Answer" : "❌ Answer"}
                    </h1>
                    <select className="px-2 py-1 bg-[#eaeaea] rounded-lg">
                      <option>{result.userAnswer}</option>
                    </select>
                  </div>
                </div>
                <p className="text-gray-500 mt-2">
                  {result.status === "right" ? "" : result.recommendation}
                </p>
              </div>
            ))}
          </div>
        </div>

        <div className="flex-row justify-center items-center">
          <button
            className="bg-[#aaaaaa] hover:bg-[#7c7979] text-white rounded-full w-fit py-2 px-4 mt-5 ml-5"
            onClick={handleManualRouter}
          >
            RE-TAKE THE QUIZ
          </button>
        </div>
      </div>
    </div>
  );
}
